@@ -58,8 +58,8 @@ def resize_image(image_path, out_path, res=(1080, 1080)):
     del img_
     del img
 
-def is_nonempty_string(string):
-    """ returns True if `string` is a non-empty str """
+def is_nonempty_string(string) -> bool:
+    """ returns True if ``string`` is a non-empty ``str`` or ``None`` """
     out = False
     if string is None:
         out = False
@@ -207,6 +207,7 @@ class Node:
                             fill="Black!5", 
                             draw="Black",
                             pos=(0,0),
+                            anchor="center",
                             line_width="thin",
                             opacity=1,
                             scale=1,
@@ -240,6 +241,24 @@ class Node:
 
         self.scale = str(scale)
 
+        anchor_dict = { 'nw':"north west",
+                        'ne':"north east",
+                        "se":"south east",
+                        "sw": "south west",
+                        "n" : "north",
+                        "s" : "south"
+                    }
+
+        if is_nonempty_string(anchor):
+            if anchor in anchor_dict.keys():
+                anchor = anchor_dict[anchor]
+            else:
+                anchor = anchor
+        else:
+            anchor = 'center'
+
+        self.anchor = anchor
+
     def parse_pos(self, pos: str) -> str:
         return parse_pos(pos)
 
@@ -250,7 +269,7 @@ class Node:
 
         self._code =        f"\\node ({self.name}) at {self.pos_str} " \
                         +   f"[{_fill_code}{_draw_code}{self.config}" \
-                        +   f",opacity={self.opacity},line width={self.line_width}" \
+                        +   f",opacity={self.opacity},line width={self.line_width},anchor={self.anchor}" \
                         +   f",rounded corners={self.rounded_corners},{self.shape},scale={self.scale}]" \
                         +    " {"+self.text+"};"
 
@@ -315,6 +334,7 @@ class Path:
             rounded_corners="0pt",
             fill="Black!5", 
             draw="Black",
+            pos=None,
             line_width="thin",
             opacity=1,
             scale=1,
@@ -344,13 +364,20 @@ class Path:
 
         scale = str(scale)
 
-        _fill_code = f"fill={fill}," if not fill is None else ""
-        _draw_code = f"draw={draw}," if not draw is None else ""
+        if pos is None:
+            pos_code = ""
+        elif isinstance(pos, (float, int)):
+            pos_code = f"pos={pos},"
+        else:
+            raise ValueError("``pos`` should be an ``int``, ``float`` or ``None``")
+
+        fill_code = f"fill={fill}," if not fill is None else ""
+        draw_code = f"draw={draw}," if not draw is None else ""
 
         code =      f"node " \
-                +   f"[{_fill_code}{_draw_code}{config}" \
-                +   f",opacity={opacity},line width={line_width}" \
-                +   f",rounded corners={rounded_corners},{shape},scale={scale}]" \
+                +   f"[{fill_code}{draw_code}{config}" \
+                +   f",opacity={opacity},line width={line_width},{pos_code}" \
+                +   f"rounded corners={rounded_corners},{shape},scale={scale}]" \
                 +    " {"+text+"} "
 
         self._code += code
@@ -658,9 +685,9 @@ class Tikz():
         draw_point_code=f"\\filldraw{Config} ({X},{Y}) circle ({radius});"
         self.write(draw_point_code)
 
-    def draw_points(self, *points, **kwordargs):
+    def draw_points(self, *points, **kwargs):
         for point in points:
-            self.draw_point(point, **kwordargs)
+            self.draw_point(point, **kwargs)
 
     def draw_vector(self, vector, start=origin,
                                   color="Black",
@@ -926,7 +953,7 @@ class Tikz():
         self.write(draw_circle_code)
 
     def draw_polygon(self, poly: Polygon, **kwargs):
-        self.draw_path(*poly.vertices, **kwargs)
+        self.draw_path(*poly.vertices, cycle=True, **kwargs)
 
     def node(self, position, node_config=def_node_config , config=def_node_draw_config, text=""):
         X,Y=row_vector(position)
@@ -947,6 +974,44 @@ class Tikz():
         code = f"\\draw{Config} plot[{plot_Config} smooth] file " + "{"+ file_path.replace("\\","/") +"};"
         self.write(code)
 
+    def smooth_plot_from_func(self, func,
+                                    x_range=[-5, 5],
+                                    samples=1000, 
+                                    **kwargs):
+
+        try:
+            os.mkdir('tables')
+        except FileExistsError:
+            pass
+
+        doc = func.__doc__ if not func.__doc__ is None else ""
+
+        indexes = []
+        for file in os.listdir(os.path.join(os.getcwd(), 'tables')):
+            if file.endswith('.table') and file.startswith('table_') and is_number(file.split(".")[0][6::]):
+                indexes.append(int(file.split(".")[0][6::]))
+        index = max(indexes) + 1 if not len(indexes)==0 else 0
+
+        table_name = f"table_{index}.table"
+        table_path = os.path.join(os.getcwd(), 'tables', table_name)
+        table = File(table_path)
+        table.create()
+
+        doc_text = ["#"+line for line in doc.splitlines()]
+        write_to_file(table_path, doc_text)
+        # write the docstring of the function as comment
+
+        X = np.linspace(*x_range, samples)
+        Y = np.vectorize(func)(X)
+
+        for x,y in zip(X, Y):
+            write_to_file(table_path, f"{x} {y}")
+
+        # write point data
+
+        self.smooth_plot_from_file(os.path.join('tables', table_name), **kwargs)
+
+
     def smooth_plot_from_points(self, points, config=def_path_config, plot_config=""):
 
         Config=f"[{config}]" if is_nonempty_string(config) else ""
